#!/bin/bash
. logging.sh

NO_THREADS=6

install_tempest() {
  mkdir -p build
  cd build
  cmake .. -DCMAKE_BUILD_TYPE=Debug -DSTORM_DEVELOPER=ON -DSTORM_LOG_DISABLE_DEBUG=OFF -DSTORM_USE_SPOT_SHIPPED=ON
  [ $? -ne 0 ] && error "Could not install tempest" && exit 1
  make storm-main -j $NO_THREADS
  [ $? -ne 0 ] && error "Could not install tempest" && exit 1
  cd ..
  echo "Installation finished, moved to:"

}

info "The installation steps for tempest are identical to those for storm, the libary it is based on:"
info "https://www.stormchecker.org/documentation/obtain-storm/build.html"
info "The dependencies for tempest are identical as well:"
info "https://www.stormchecker.org/documentation/obtain-storm/dependencies.html"

info "Installing dependencies:"
sleep 0.2
set -x
sudo apt-get install build-essential git cmake libboost-all-dev libcln-dev libgmp-dev libginac-dev automake libglpk-dev libhwloc-dev libz3-dev libxerces-c-dev libeigen3-dev
set +x

if [ -d ./carl ]; then
  info "carl directory exists"
else
  git clone -b c++14-22.01 https://github.com/ths-rwth/carl.git
  mkdir -p carl/build
  cd carl/build
  cmake ..
  make lib_carl
  cd ../..
fi


if [ -d ./tempest ]; then
  info "tempest directory exists"
  info "Checking if tempest is installed..."
  cd tempest
  ./build/bin/storm
  [ $? -ne 0 ] && warning "tempest is not installed, running install script" && install_tempest
else
  git clone -b tempestpy_adaptions https://git.pranger.xyz/sp/tempest.git
  mkdir -p tempest/build
  cd tempest
  install_tempest
  pwd
fi

echo "You can optionally add tempest to your path (you might need to change the rc-file appropriately):"
echo "echo 'export PATH=\$PATH:$(pwd)/build/bin' >> ~/.bashrc"
