#!/bin/bash
. logging.sh

TEMPEST_IMAGE_NAME=tempest/tempest_development
TEMPEST_IMAGE_TAG=0.1
TEMPEST_CONTAINER_NAME=tempest_development
EXAMPLES_DIR=examples
NO_THREADS=6

if ! command -v docker 2>&1 >/dev/null
then
  error "docker is not installed"
  error "Please refer to https://docs.docker.com/desktop/install/linux/ to install docker"
  exit 1
fi

if [ -d ./tempest ]; then
  info "tempest directory exists"
else
  info "Cloning tempest"
  git clone -b tempestpy_adaptions https://git.pranger.xyz/sp/tempest.git
fi

[ -d ./$EXAMPLES_DIR ] || info "Creating examples directory: ./$EXAMPLES_DIR" && mkdir -p $EXAMPLES_DIR


# if container is already running, exec bash in container OR do not remove container
info "Checking if container '$TEMPEST_CONTAINER_NAME' is present"
if [ "$(sudo docker ps -a -q -f name=$TEMPEST_CONTAINER_NAME)" ]; then
  info "Docker container $TEMPEST_CONTAINER_NAME is still present"
  info "Restarting container..."
  sudo docker restart $TEMPEST_CONTAINER_NAME
  sudo docker exec -it $TEMPEST_CONTAINER_NAME /bin/bash
else
  info "Starting docker container..."
  if [ -z "$(sudo docker images -q $TEMPEST_IMAGE_NAME:$TEMPEST_IMAGE_TAG 2> /dev/null)" ]; then
    warning "docker image not available"
    info "Installing docker image $TEMPEST_IMAGE_NAME:$TEMPEST_IMAGE_TAG"
    sudo docker build -t $TEMPEST_IMAGE_NAME:$TEMPEST_IMAGE_TAG -f DockerfileBuildDev .
  else
    info "docker image available"
    info "When running for the first time, build tempest with either:"
    info "cmake .. -DCMAKE_BUILD_TYPE=Debug -DSTORM_DEVELOPER=ON -DSTORM_LOG_DISABLE_DEBUG=OFF -DSTORM_USE_SPOT_SHIPPED=ON"
    info "or"
    info "cmake .. -DCMAKE_BUILD_TYPE=Release -DSTORM_DEVELOPER=OFF -DSTORM_LOG_DISABLE_DEBUG=ON -DSTORM_PORTABLE=OFF -DSTORM_USE_SPOT_SHIPPED=ON"
    info "followed by"
    info "make storm-main -j <numberofcores"
    info "You can use >=6 cores if you have more than 8GB of RAM available"

    sudo docker run -it --name=$TEMPEST_CONTAINER_NAME \
   --mount type=bind,source=${PWD}/tempest,target=/opt/tempest \
   --mount type=bind,source=${PWD}/$EXAMPLES_DIR,target=/opt/examples \
   $TEMPEST_IMAGE_NAME:$TEMPEST_IMAGE_TAG \
   bash
  fi
fi
